@@ -1,16 +1,18 @@
-#   Copyright 2019 AUI, Inc. Washington DC, USA
+#  CASA Next Generation Infrastructure
+#  Copyright (C) 2021 AUI, Inc. Washington DC, USA
 #
-#   Licensed under the Apache License, Version 2.0 (the "License");
-#   you may not use this file except in compliance with the License.
-#   You may obtain a copy of the License at
+#  This program is free software: you can redistribute it and/or modify
+#  it under the terms of the GNU General Public License as published by
+#  the Free Software Foundation, either version 3 of the License, or
+#  (at your option) any later version.
 #
-#       http://www.apache.org/licenses/LICENSE-2.0
+#  This program is distributed in the hope that it will be useful,
+#  but WITHOUT ANY WARRANTY; without even the implied warranty of
+#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+#  GNU General Public License for more details.
 #
-#   Unless required by applicable law or agreed to in writing, software
-#   distributed under the License is distributed on an "AS IS" BASIS,
-#   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-#   See the License for the specific language governing permissions and
-#   limitations under the License.
+#  You should have received a copy of the GNU General Public License
+#  along with this program.  If not, see <https://www.gnu.org/licenses/>.
 """
 this module will be included in the api
 """
@@ -180,6 +182,7 @@ def convert_image(infile, outfile=None, artifacts=[], compressor=None, chunks=(-
 
     # if taylor terms are present, the chan axis must be expanded to the length of the terms
     if ttcount > len(mxds.chan): mxds = mxds.pad({'chan': (0, ttcount-len(mxds.chan))}, mode='edge')
+   
     
     chunk_dict = dict(zip(['l','m','time','chan','pol'], chunks[:2]+(1,)+chunks[2:]))
     mxds = mxds.chunk(chunk_dict)
@@ -219,7 +222,12 @@ def convert_image(infile, outfile=None, artifacts=[], compressor=None, chunks=(-
 
     # add attributes from metadata and version tag file
     mxds.to_zarr(outfile, mode='a', compute=True, consolidated=True)
+    try:
+        version = importlib_metadata.version('cngi-prototype')
+    except:
+        version = '0.0.0'
+
     with open(outfile + '/.version', 'w') as fid:   # write sw version that did this conversion to zarr directory
-        fid.write('cngi-protoype ' + importlib_metadata.version('cngi-prototype') + '\n')
+        fid.write('cngi-protoype ' + version + '\n')
 
     return xarray.open_zarr(outfile)
